__all__ = []


def _everything(*args, **kwargs):
    raise NotImplementedError('''This is not the timescape package you are looking for.

Do not blindly install packages from PyPI. Ask for instructions from whomever asked you to install this.

I have registered this project to prevent name-squatting by a bad actor, and all names will raise this error.''')


def __getattr__(name):
    return _everything



from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = ''.join(f.readlines())

setup(
    name='timescape',
    version='1.0',
    packages=find_packages(),
    description="Placeholder for the timescape name",
    long_description=long_description
)
